@@ -1,7 +1,6 @@
 """Alexa entity adapters."""
 import logging
 from typing import List
-from urllib.parse import urlparse
 
 from homeassistant.components import (
     alarm_control_panel,
@@ -252,7 +251,6 @@ class AlexaEntity:
 
         Raises _UnsupportedInterface.
         """
-        pass
 
     def interfaces(self):
         """Return a list of supported interfaces.
@@ -268,8 +266,7 @@ class AlexaEntity:
             if not interface.properties_proactively_reported():
                 continue
 
-            for prop in interface.serialize_properties():
-                yield prop
+            yield from interface.serialize_properties()
 
     def serialize_discovery(self):
         """Serialize the entity for discovery."""
@@ -283,10 +280,12 @@ class AlexaEntity:
         }
 
         locale = self.config.locale
-        capabilities = []
-        for i in self.interfaces():
-            if locale in i.supported_locales:
-                capabilities.append(i.serialize_discovery())
+        capabilities = [
+            i.serialize_discovery()
+            for i in self.interfaces()
+            if locale in i.supported_locales
+        ]
+
         result["capabilities"] = capabilities
 
         return result
@@ -386,7 +385,7 @@ class CoverCapabilities(AlexaEntity):
     def default_display_categories(self):
         """Return the display categories for this entity."""
         device_class = self.entity.attributes.get(ATTR_DEVICE_CLASS)
-        if device_class == cover.DEVICE_CLASS_GARAGE:
+        if device_class in (cover.DEVICE_CLASS_GARAGE, cover.DEVICE_CLASS_GATE):
             return [DisplayCategory.GARAGE_DOOR]
         if device_class == cover.DEVICE_CLASS_DOOR:
             return [DisplayCategory.DOOR]
@@ -408,7 +407,7 @@ class CoverCapabilities(AlexaEntity):
     def interfaces(self):
         """Yield the supported interfaces."""
         device_class = self.entity.attributes.get(ATTR_DEVICE_CLASS)
-        if device_class != cover.DEVICE_CLASS_GARAGE:
+        if device_class not in (cover.DEVICE_CLASS_GARAGE, cover.DEVICE_CLASS_GATE):
             yield AlexaPowerController(self.entity)
 
         supported = self.entity.attributes.get(ATTR_SUPPORTED_FEATURES, 0)
@@ -799,8 +798,15 @@ class CameraCapabilities(AlexaEntity):
             )
             return False
 
-        url = urlparse(network.async_get_external_url(self.hass))
-        if url.scheme != "https":
+        try:
+            network.get_url(
+                self.hass,
+                allow_internal=False,
+                allow_ip=False,
+                require_ssl=True,
+                require_standard_port=True,
+            )
+        except network.NoURLAvailableError:
             _LOGGER.debug(
                 "%s requires HTTPS for AlexaCameraStreamController", self.entity_id
             )
