@@ -7,7 +7,7 @@ import requests
 import somecomfort
 import voluptuous as vol
 
-from homeassistant.components.climate import PLATFORM_SCHEMA, ClimateDevice
+from homeassistant.components.climate import PLATFORM_SCHEMA, ClimateEntity
 from homeassistant.components.climate.const import (
     ATTR_TARGET_TEMP_HIGH,
     ATTR_TARGET_TEMP_LOW,
@@ -145,7 +145,7 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
     )
 
 
-class HoneywellUSThermostat(ClimateDevice):
+class HoneywellUSThermostat(ClimateEntity):
     """Representation of a Honeywell US Thermostat."""
 
     def __init__(
