@@ -22,6 +22,8 @@ KEY_ID = "id"
 KEY_NAME = "name"
 KEY_MODEL = "model"
 KEY_ON = "on"
+KEY_DURATION = "totalDuration"
+KEY_RAIN_DELAY = "rainDelayExpirationDate"
 KEY_STATUS = "status"
 KEY_SUBTYPE = "subType"
 KEY_SUMMARY = "summary"
@@ -33,6 +35,9 @@ KEY_USERNAME = "username"
 KEY_ZONE_ID = "zoneId"
 KEY_ZONE_NUMBER = "zoneNumber"
 KEY_ZONES = "zones"
+KEY_SCHEDULES = "scheduleRules"
+KEY_FLEX_SCHEDULES = "flexScheduleRules"
+KEY_SCHEDULE_ID = "scheduleId"
 KEY_CUSTOM_SHADE = "customShade"
 KEY_CUSTOM_CROP = "customCrop"
 
@@ -48,9 +53,12 @@ RACHIO_API_EXCEPTIONS = (
 )
 
 STATUS_ONLINE = "ONLINE"
-STATUS_OFFLINE = "OFFLINE"
 
-SIGNAL_RACHIO_UPDATE = DOMAIN + "_update"
-SIGNAL_RACHIO_CONTROLLER_UPDATE = SIGNAL_RACHIO_UPDATE + "_controller"
-SIGNAL_RACHIO_ZONE_UPDATE = SIGNAL_RACHIO_UPDATE + "_zone"
-SIGNAL_RACHIO_SCHEDULE_UPDATE = SIGNAL_RACHIO_UPDATE + "_schedule"
+SIGNAL_RACHIO_UPDATE = f"{DOMAIN}_update"
+SIGNAL_RACHIO_CONTROLLER_UPDATE = f"{SIGNAL_RACHIO_UPDATE}_controller"
+SIGNAL_RACHIO_RAIN_DELAY_UPDATE = f"{SIGNAL_RACHIO_UPDATE}_rain_delay"
+SIGNAL_RACHIO_ZONE_UPDATE = f"{SIGNAL_RACHIO_UPDATE}_zone"
+SIGNAL_RACHIO_SCHEDULE_UPDATE = f"{SIGNAL_RACHIO_UPDATE}_schedule"
+
+CONF_WEBHOOK_ID = "webhook_id"
+CONF_CLOUDHOOK_URL = "cloudhook_url"
