@@ -29,6 +29,7 @@ from homeassistant.helpers.config_validation import make_entity_service_schema
 from homeassistant.helpers.entity import Entity
 from homeassistant.helpers.entity_component import EntityComponent
 from homeassistant.helpers.event import track_time_interval
+from homeassistant.helpers.network import get_url
 from homeassistant.util.json import load_json, save_json
 
 _LOGGER = logging.getLogger(__name__)
@@ -231,17 +232,15 @@ def _request_app_setup(hass, config):
         _configurator = hass.data[DOMAIN]["configuring"][DOMAIN]
         configurator.notify_errors(_configurator, error_msg)
 
-    start_url = f"{hass.config.api.base_url}{WINK_AUTH_CALLBACK_PATH}"
+    start_url = f"{get_url(hass)}{WINK_AUTH_CALLBACK_PATH}"
 
-    description = """Please create a Wink developer app at
+    description = f"""Please create a Wink developer app at
                      https://developer.wink.com.
-                     Add a Redirect URI of {}.
+                     Add a Redirect URI of {start_url}.
                      They will provide you a Client ID and secret
                      after reviewing your request.
                      (This can take several days).
-                     """.format(
-        start_url
-    )
+                     """
 
     hass.data[DOMAIN]["configuring"][DOMAIN] = configurator.request_config(
         DOMAIN,
@@ -271,7 +270,7 @@ def _request_oauth_completion(hass, config):
         """Call setup again."""
         setup(hass, config)
 
-    start_url = f"{hass.config.api.base_url}{WINK_AUTH_START}"
+    start_url = f"{get_url(hass)}{WINK_AUTH_START}"
 
     description = f"Please authorize Wink by visiting {start_url}"
 
@@ -351,9 +350,7 @@ def setup(hass, config):
         # Home .
         else:
 
-            redirect_uri = "{}{}".format(
-                hass.config.api.base_url, WINK_AUTH_CALLBACK_PATH
-            )
+            redirect_uri = f"{get_url(hass)}{WINK_AUTH_CALLBACK_PATH}"
 
             wink_auth_start_url = pywink.get_authorization_url(
                 config_file.get(ATTR_CLIENT_ID), redirect_uri
@@ -749,7 +746,7 @@ class WinkDevice(Entity):
                 self.schedule_update_ha_state()
         except (ValueError, KeyError, AttributeError):
             _LOGGER.error(
-                "Error in pubnub JSON for %s polling API for current state", self.name,
+                "Error in pubnub JSON for %s polling API for current state", self.name
             )
             self.schedule_update_ha_state(True)
 
@@ -762,7 +759,7 @@ class WinkDevice(Entity):
     def unique_id(self):
         """Return the unique id of the Wink device."""
         if hasattr(self.wink, "capability") and self.wink.capability() is not None:
-            return "{}_{}".format(self.wink.object_id(), self.wink.capability())
+            return f"{self.wink.object_id()}_{self.wink.capability()}"
         return self.wink.object_id()
 
     @property
@@ -912,7 +909,7 @@ class WinkNimbusDialDevice(WinkDevice):
     @property
     def name(self):
         """Return the name of the device."""
-        return self.parent.name() + " dial " + str(self.wink.index() + 1)
+        return f"{self.parent.name()} dial {self.wink.index() + 1}"
 
     @property
     def device_state_attributes(self):
