@@ -465,6 +465,15 @@ def string(value: Any) -> str:
     return str(value)
 
 
+def string_with_no_html(value: Any) -> str:
+    """Validate that the value is a string without HTML."""
+    value = string(value)
+    regex = re.compile(r"<[a-z][\s\S]*>")
+    if regex.search(value):
+        raise vol.Invalid("the string should not contain HTML")
+    return str(value)
+
+
 def temperature_unit(value: Any) -> str:
     """Validate and transform temperature unit."""
     value = str(value).upper()
@@ -924,6 +933,17 @@ OR_CONDITION_SCHEMA = vol.Schema(
     }
 )
 
+NOT_CONDITION_SCHEMA = vol.Schema(
+    {
+        vol.Required(CONF_CONDITION): "not",
+        vol.Required("conditions"): vol.All(
+            ensure_list,
+            # pylint: disable=unnecessary-lambda
+            [lambda value: CONDITION_SCHEMA(value)],
+        ),
+    }
+)
+
 DEVICE_CONDITION_BASE_SCHEMA = vol.Schema(
     {
         vol.Required(CONF_CONDITION): "device",
@@ -945,6 +965,7 @@ CONDITION_SCHEMA: vol.Schema = key_value_schemas(
         "zone": ZONE_CONDITION_SCHEMA,
         "and": AND_CONDITION_SCHEMA,
         "or": OR_CONDITION_SCHEMA,
+        "not": NOT_CONDITION_SCHEMA,
         "device": DEVICE_CONDITION_SCHEMA,
     },
 )
